==> apigatewaylambda-1.69.0-sources.jar: software/amazon/awsconstructs/services/apigatewaylambda/ApiGatewayToLambdaProps.java <==
package software.amazon.awsconstructs.services.apigatewaylambda;

/**
 * The properties for the ApiGatewayToLambda class.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.13.0 (build 385c325)", date = "2020-10-21T23:16:23.049Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.apigatewaylambda.$Module.class, fqn = "@aws-solutions-constructs/aws-apigateway-lambda.ApiGatewayToLambdaProps")
@software.amazon.jsii.Jsii.Proxy(ApiGatewayToLambdaProps.Jsii$Proxy.class)
public interface ApiGatewayToLambdaProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Optional user-provided props to override the default props for the API.
     * <p>
     * Default: - Default props are used.
     */
    default @org.jetbrains.annotations.Nullable java.lang.Object getApiGatewayProps() {
        return null;
    }

    /**
     * Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
        return null;
    }

    /**
     * User provided props to override the default props for the Lambda function.
     * <p>
     * Default: - Default props are used.
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ApiGatewayToLambdaProps}
     */
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ApiGatewayToLambdaProps}
     */
    public static final class Builder implements software.amazon.jsii.Builder<ApiGatewayToLambdaProps> {
        private java.lang.Object apiGatewayProps;
        private software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;

        /**
         * Sets the value of {@link ApiGatewayToLambdaProps#getApiGatewayProps}
         * @param apiGatewayProps Optional user-provided props to override the default props for the API.
         * @return {@code this}
         */
        public Builder apiGatewayProps(java.lang.Object apiGatewayProps) {
            this.apiGatewayProps = apiGatewayProps;
            return this;
        }

        /**
         * Sets the value of {@link ApiGatewayToLambdaProps#getExistingLambdaObj}
         * @param existingLambdaObj Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
         * @return {@code this}
         */
        public Builder existingLambdaObj(software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.existingLambdaObj = existingLambdaObj;
            return this;
        }

        /**
         * Sets the value of {@link ApiGatewayToLambdaProps#getLambdaFunctionProps}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function.
         * @return {@code this}
         */
        public Builder lambdaFunctionProps(software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.lambdaFunctionProps = lambdaFunctionProps;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ApiGatewayToLambdaProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @Override
        public ApiGatewayToLambdaProps build() {
            return new Jsii$Proxy(apiGatewayProps, existingLambdaObj, lambdaFunctionProps);
        }
    }

    /**
     * An implementation for {@link ApiGatewayToLambdaProps}
     */
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ApiGatewayToLambdaProps {
        private final java.lang.Object apiGatewayProps;
        private final software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.apiGatewayProps = this.jsiiGet("apiGatewayProps", java.lang.Object.class);
            this.existingLambdaObj = this.jsiiGet("existingLambdaObj", software.amazon.awscdk.services.lambda.Function.class);
            this.lambdaFunctionProps = this.jsiiGet("lambdaFunctionProps", software.amazon.awscdk.services.lambda.FunctionProps.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Object apiGatewayProps, final software.amazon.awscdk.services.lambda.Function existingLambdaObj, final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.apiGatewayProps = apiGatewayProps;
            this.existingLambdaObj = existingLambdaObj;
            this.lambdaFunctionProps = lambdaFunctionProps;
        }

        @Override
        public java.lang.Object getApiGatewayProps() {
            return this.apiGatewayProps;
        }

        @Override
        public software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
            return this.existingLambdaObj;
        }

        @Override
        public software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
            return this.lambdaFunctionProps;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getApiGatewayProps() != null) {
                data.set("apiGatewayProps", om.valueToTree(this.getApiGatewayProps()));
            }
            if (this.getExistingLambdaObj() != null) {
                data.set("existingLambdaObj", om.valueToTree(this.getExistingLambdaObj()));
            }
            if (this.getLambdaFunctionProps() != null) {
                data.set("lambdaFunctionProps", om.valueToTree(this.getLambdaFunctionProps()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-solutions-constructs/aws-apigateway-lambda.ApiGatewayToLambdaProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ApiGatewayToLambdaProps.Jsii$Proxy that = (ApiGatewayToLambdaProps.Jsii$Proxy) o;

            if (this.apiGatewayProps != null ? !this.apiGatewayProps.equals(that.apiGatewayProps) : that.apiGatewayProps != null) return false;
            if (this.existingLambdaObj != null ? !this.existingLambdaObj.equals(that.existingLambdaObj) : that.existingLambdaObj != null) return false;
            return this.lambdaFunctionProps != null ? this.lambdaFunctionProps.equals(that.lambdaFunctionProps) : that.lambdaFunctionProps == null;
        }

        @Override
        public int hashCode() {
            int result = this.apiGatewayProps != null ? this.apiGatewayProps.hashCode() : 0;
            result = 31 * result + (this.existingLambdaObj != null ? this.existingLambdaObj.hashCode() : 0);
            result = 31 * result + (this.lambdaFunctionProps != null ? this.lambdaFunctionProps.hashCode() : 0);
            return result;
        }
    }
}

==> apigatewaylambda-1.81.0-sources.jar: software/amazon/awsconstructs/services/apigatewaylambda/ApiGatewayToLambdaProps.java <==
package software.amazon.awsconstructs.services.apigatewaylambda;

/**
 * The properties for the ApiGatewayToLambda class.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.17.1 (build 2bac5fd)", date = "2021-01-14T19:02:32.905Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.apigatewaylambda.$Module.class, fqn = "@aws-solutions-constructs/aws-apigateway-lambda.ApiGatewayToLambdaProps")
@software.amazon.jsii.Jsii.Proxy(ApiGatewayToLambdaProps.Jsii$Proxy.class)
public interface ApiGatewayToLambdaProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Optional user-provided props to override the default props for the API.
     * <p>
     * Default: - Default props are used.
     */
    default @org.jetbrains.annotations.Nullable java.lang.Object getApiGatewayProps() {
        return null;
    }

    /**
     * Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
        return null;
    }

    /**
     * User provided props to override the default props for the Lambda function.
     * <p>
     * Default: - Default props are used.
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ApiGatewayToLambdaProps}
     */
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ApiGatewayToLambdaProps}
     */
    public static final class Builder implements software.amazon.jsii.Builder<ApiGatewayToLambdaProps> {
        private java.lang.Object apiGatewayProps;
        private software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;

        /**
         * Sets the value of {@link ApiGatewayToLambdaProps#getApiGatewayProps}
         * @param apiGatewayProps Optional user-provided props to override the default props for the API.
         * @return {@code this}
         */
        public Builder apiGatewayProps(java.lang.Object apiGatewayProps) {
            this.apiGatewayProps = apiGatewayProps;
            return this;
        }

        /**
         * Sets the value of {@link ApiGatewayToLambdaProps#getExistingLambdaObj}
         * @param existingLambdaObj Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
         * @return {@code this}
         */
        public Builder existingLambdaObj(software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.existingLambdaObj = existingLambdaObj;
            return this;
        }

        /**
         * Sets the value of {@link ApiGatewayToLambdaProps#getLambdaFunctionProps}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function.
         * @return {@code this}
         */
        public Builder lambdaFunctionProps(software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.lambdaFunctionProps = lambdaFunctionProps;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ApiGatewayToLambdaProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @Override
        public ApiGatewayToLambdaProps build() {
            return new Jsii$Proxy(apiGatewayProps, existingLambdaObj, lambdaFunctionProps);
        }
    }

    /**
     * An implementation for {@link ApiGatewayToLambdaProps}
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ApiGatewayToLambdaProps {
        private final java.lang.Object apiGatewayProps;
        private final software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.apiGatewayProps = software.amazon.jsii.Kernel.get(this, "apiGatewayProps", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.existingLambdaObj = software.amazon.jsii.Kernel.get(this, "existingLambdaObj", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
            this.lambdaFunctionProps = software.amazon.jsii.Kernel.get(this, "lambdaFunctionProps", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.FunctionProps.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.Object apiGatewayProps, final software.amazon.awscdk.services.lambda.Function existingLambdaObj, final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.apiGatewayProps = apiGatewayProps;
            this.existingLambdaObj = existingLambdaObj;
            this.lambdaFunctionProps = lambdaFunctionProps;
        }

        @Override
        public final java.lang.Object getApiGatewayProps() {
            return this.apiGatewayProps;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
            return this.existingLambdaObj;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
            return this.lambdaFunctionProps;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getApiGatewayProps() != null) {
                data.set("apiGatewayProps", om.valueToTree(this.getApiGatewayProps()));
            }
            if (this.getExistingLambdaObj() != null) {
                data.set("existingLambdaObj", om.valueToTree(this.getExistingLambdaObj()));
            }
            if (this.getLambdaFunctionProps() != null) {
                data.set("lambdaFunctionProps", om.valueToTree(this.getLambdaFunctionProps()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-solutions-constructs/aws-apigateway-lambda.ApiGatewayToLambdaProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ApiGatewayToLambdaProps.Jsii$Proxy that = (ApiGatewayToLambdaProps.Jsii$Proxy) o;

            if (this.apiGatewayProps != null ? !this.apiGatewayProps.equals(that.apiGatewayProps) : that.apiGatewayProps != null) return false;
            if (this.existingLambdaObj != null ? !this.existingLambdaObj.equals(that.existingLambdaObj) : that.existingLambdaObj != null) return false;
            return this.lambdaFunctionProps != null ? this.lambdaFunctionProps.equals(that.lambdaFunctionProps) : that.lambdaFunctionProps == null;
        }

        @Override
        public final int hashCode() {
            int result = this.apiGatewayProps != null ? this.apiGatewayProps.hashCode() : 0;
            result = 31 * result + (this.existingLambdaObj != null ? this.existingLambdaObj.hashCode() : 0);
            result = 31 * result + (this.lambdaFunctionProps != null ? this.lambdaFunctionProps.hashCode() : 0);
            return result;
        }
    }
}
